Module: Google::Apis::MeetV2

Defined in:
lib/google/apis/meet_v2.rb,
lib/google/apis/meet_v2/classes.rb,
lib/google/apis/meet_v2/service.rb,
lib/google/apis/meet_v2/gem_version.rb,
lib/google/apis/meet_v2/representations.rb

Overview

Google Meet API

Create and manage meetings in Google Meet.

Defined Under Namespace

Classes: ActiveConference, AnonymousUser, ArtifactConfig, ConferenceRecord, DocsDestination, DriveDestination, Empty, EndActiveConferenceRequest, GatewaySipAccess, ListConferenceRecordsResponse, ListParticipantSessionsResponse, ListParticipantsResponse, ListRecordingsResponse, ListSmartNotesResponse, ListTranscriptEntriesResponse, ListTranscriptsResponse, MeetService, ModerationRestrictions, Participant, ParticipantSession, PhoneAccess, PhoneUser, Recording, RecordingConfig, SignedinUser, SmartNote, SmartNotesConfig, Space, SpaceConfig, Transcript, TranscriptEntry, TranscriptionConfig

Constant Summary collapse

GEM_VERSION =

Version of the google-apis-meet_v2 gem

"0.12.0"
GENERATOR_VERSION =

Version of the code generator used to generate this client

"0.18.0"
REVISION =

Revision of the discovery document this client was generated from

"20260329"
VERSION =

Version of the Google Meet API this client connects to. This is NOT the gem version.

'V2'
AUTH_MEETINGS_SPACE_CREATED =

Create, edit, and see information about your Google Meet conferences created by the app.

'https://www.googleapis.com/auth/meetings.space.created'
AUTH_MEETINGS_SPACE_READONLY =

Read information about any of your Google Meet conferences

'https://www.googleapis.com/auth/meetings.space.readonly'
AUTH_MEETINGS_SPACE_SETTINGS =

Edit, and see settings for all of your Google Meet calls.

'https://www.googleapis.com/auth/meetings.space.settings'