Class: Google::Apis::MeetV2::ArtifactConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/meet_v2/classes.rb,
lib/google/apis/meet_v2/representations.rb,
lib/google/apis/meet_v2/representations.rb

Overview

Configuration related to meeting artifacts potentially generated by this meeting space.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ArtifactConfig

Returns a new instance of ArtifactConfig.



87
88
89
# File 'lib/google/apis/meet_v2/classes.rb', line 87

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#recording_configGoogle::Apis::MeetV2::RecordingConfig

Configuration related to recording in a meeting space. Corresponds to the JSON property recordingConfig



73
74
75
# File 'lib/google/apis/meet_v2/classes.rb', line 73

def recording_config
  @recording_config
end

#smart_notes_configGoogle::Apis::MeetV2::SmartNotesConfig

Configuration related to smart notes in a meeting space. For more information about smart notes, see "Take notes for me" in Google Meet. Corresponds to the JSON property smartNotesConfig



80
81
82
# File 'lib/google/apis/meet_v2/classes.rb', line 80

def smart_notes_config
  @smart_notes_config
end

#transcription_configGoogle::Apis::MeetV2::TranscriptionConfig

Configuration related to transcription in a meeting space. Corresponds to the JSON property transcriptionConfig



85
86
87
# File 'lib/google/apis/meet_v2/classes.rb', line 85

def transcription_config
  @transcription_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



92
93
94
95
96
# File 'lib/google/apis/meet_v2/classes.rb', line 92

def update!(**args)
  @recording_config = args[:recording_config] if args.key?(:recording_config)
  @smart_notes_config = args[:smart_notes_config] if args.key?(:smart_notes_config)
  @transcription_config = args[:transcription_config] if args.key?(:transcription_config)
end