Class: Google::Apis::MeetV2::ConferenceRecord

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/meet_v2/classes.rb,
lib/google/apis/meet_v2/representations.rb,
lib/google/apis/meet_v2/representations.rb

Overview

Single instance of a meeting held in a space.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConferenceRecord

Returns a new instance of ConferenceRecord.



132
133
134
# File 'lib/google/apis/meet_v2/classes.rb', line 132

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_timeString

Output only. Timestamp when the conference ended. Set for past conferences. Unset if the conference is ongoing. Corresponds to the JSON property endTime

Returns:

  • (String)


107
108
109
# File 'lib/google/apis/meet_v2/classes.rb', line 107

def end_time
  @end_time
end

#expire_timeString

Output only. Server enforced expiration time for when this conference record resource is deleted. The resource is deleted 30 days after the conference ends. Corresponds to the JSON property expireTime

Returns:

  • (String)


113
114
115
# File 'lib/google/apis/meet_v2/classes.rb', line 113

def expire_time
  @expire_time
end

#nameString

Identifier. Resource name of the conference record. Format: conferenceRecords/ conference_recordwhereconference_record`is a unique ID for each instance of a call within a space. Corresponds to the JSON propertyname`

Returns:

  • (String)


120
121
122
# File 'lib/google/apis/meet_v2/classes.rb', line 120

def name
  @name
end

#spaceString

Output only. The space where the conference was held. Corresponds to the JSON property space

Returns:

  • (String)


125
126
127
# File 'lib/google/apis/meet_v2/classes.rb', line 125

def space
  @space
end

#start_timeString

Output only. Timestamp when the conference started. Always set. Corresponds to the JSON property startTime

Returns:

  • (String)


130
131
132
# File 'lib/google/apis/meet_v2/classes.rb', line 130

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



137
138
139
140
141
142
143
# File 'lib/google/apis/meet_v2/classes.rb', line 137

def update!(**args)
  @end_time = args[:end_time] if args.key?(:end_time)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @name = args[:name] if args.key?(:name)
  @space = args[:space] if args.key?(:space)
  @start_time = args[:start_time] if args.key?(:start_time)
end