Class: Google::Apis::MeetV2::ListConferenceRecordsResponse
- Inherits:
-
Object
- Object
- Google::Apis::MeetV2::ListConferenceRecordsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/meet_v2/classes.rb,
lib/google/apis/meet_v2/representations.rb,
lib/google/apis/meet_v2/representations.rb
Overview
Response of ListConferenceRecords method.
Instance Attribute Summary collapse
-
#conference_records ⇒ Array<Google::Apis::MeetV2::ConferenceRecord>
List of conferences in one page.
-
#next_page_token ⇒ String
Token to be circulated back for further List call if current List does NOT include all the Conferences.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListConferenceRecordsResponse
constructor
A new instance of ListConferenceRecordsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListConferenceRecordsResponse
Returns a new instance of ListConferenceRecordsResponse.
278 279 280 |
# File 'lib/google/apis/meet_v2/classes.rb', line 278 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conference_records ⇒ Array<Google::Apis::MeetV2::ConferenceRecord>
List of conferences in one page.
Corresponds to the JSON property conferenceRecords
270 271 272 |
# File 'lib/google/apis/meet_v2/classes.rb', line 270 def conference_records @conference_records end |
#next_page_token ⇒ String
Token to be circulated back for further List call if current List does NOT
include all the Conferences. Unset if all conferences have been returned.
Corresponds to the JSON property nextPageToken
276 277 278 |
# File 'lib/google/apis/meet_v2/classes.rb', line 276 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
283 284 285 286 |
# File 'lib/google/apis/meet_v2/classes.rb', line 283 def update!(**args) @conference_records = args[:conference_records] if args.key?(:conference_records) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |