Class: Google::Apis::MeetV2::ListParticipantSessionsResponse
- Inherits:
-
Object
- Object
- Google::Apis::MeetV2::ListParticipantSessionsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/meet_v2/classes.rb,
lib/google/apis/meet_v2/representations.rb,
lib/google/apis/meet_v2/representations.rb
Overview
Response of ListParticipants method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Token to be circulated back for further List call if current List doesn't include all the participants.
-
#participant_sessions ⇒ Array<Google::Apis::MeetV2::ParticipantSession>
List of participants in one page.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListParticipantSessionsResponse
constructor
A new instance of ListParticipantSessionsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListParticipantSessionsResponse
Returns a new instance of ListParticipantSessionsResponse.
304 305 306 |
# File 'lib/google/apis/meet_v2/classes.rb', line 304 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Token to be circulated back for further List call if current List doesn't
include all the participants. Unset if all participants are returned.
Corresponds to the JSON property nextPageToken
297 298 299 |
# File 'lib/google/apis/meet_v2/classes.rb', line 297 def next_page_token @next_page_token end |
#participant_sessions ⇒ Array<Google::Apis::MeetV2::ParticipantSession>
List of participants in one page.
Corresponds to the JSON property participantSessions
302 303 304 |
# File 'lib/google/apis/meet_v2/classes.rb', line 302 def participant_sessions @participant_sessions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
309 310 311 312 |
# File 'lib/google/apis/meet_v2/classes.rb', line 309 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @participant_sessions = args[:participant_sessions] if args.key?(:participant_sessions) end |