Class: Google::Apis::MeetV2::ListParticipantsResponse
- Inherits:
-
Object
- Object
- Google::Apis::MeetV2::ListParticipantsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/meet_v2/classes.rb,
lib/google/apis/meet_v2/representations.rb,
lib/google/apis/meet_v2/representations.rb
Overview
Response of ListParticipants method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Token to be circulated back for further List call if current List doesn't include all the participants.
-
#participants ⇒ Array<Google::Apis::MeetV2::Participant>
List of participants in one page.
-
#total_size ⇒ Fixnum
Total, exact number of
participants.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListParticipantsResponse
constructor
A new instance of ListParticipantsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListParticipantsResponse
Returns a new instance of ListParticipantsResponse.
337 338 339 |
# File 'lib/google/apis/meet_v2/classes.rb', line 337 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Token to be circulated back for further List call if current List doesn't
include all the participants. Unset if all participants are returned.
Corresponds to the JSON property nextPageToken
323 324 325 |
# File 'lib/google/apis/meet_v2/classes.rb', line 323 def next_page_token @next_page_token end |
#participants ⇒ Array<Google::Apis::MeetV2::Participant>
List of participants in one page.
Corresponds to the JSON property participants
328 329 330 |
# File 'lib/google/apis/meet_v2/classes.rb', line 328 def participants @participants end |
#total_size ⇒ Fixnum
Total, exact number of participants. By default, this field isn't included
in the response. Set the field mask in SystemParameterContext to receive this field in the response.
Corresponds to the JSON property totalSize
335 336 337 |
# File 'lib/google/apis/meet_v2/classes.rb', line 335 def total_size @total_size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
342 343 344 345 346 |
# File 'lib/google/apis/meet_v2/classes.rb', line 342 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @participants = args[:participants] if args.key?(:participants) @total_size = args[:total_size] if args.key?(:total_size) end |