Class: Google::Apis::MeetV2::ListRecordingsResponse
- Inherits:
-
Object
- Object
- Google::Apis::MeetV2::ListRecordingsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/meet_v2/classes.rb,
lib/google/apis/meet_v2/representations.rb,
lib/google/apis/meet_v2/representations.rb
Overview
Response for ListRecordings method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Token to be circulated back for further List call if current List doesn't include all the recordings.
-
#recordings ⇒ Array<Google::Apis::MeetV2::Recording>
List of recordings in one page.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListRecordingsResponse
constructor
A new instance of ListRecordingsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListRecordingsResponse
Returns a new instance of ListRecordingsResponse.
364 365 366 |
# File 'lib/google/apis/meet_v2/classes.rb', line 364 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Token to be circulated back for further List call if current List doesn't
include all the recordings. Unset if all recordings are returned.
Corresponds to the JSON property nextPageToken
357 358 359 |
# File 'lib/google/apis/meet_v2/classes.rb', line 357 def next_page_token @next_page_token end |
#recordings ⇒ Array<Google::Apis::MeetV2::Recording>
List of recordings in one page.
Corresponds to the JSON property recordings
362 363 364 |
# File 'lib/google/apis/meet_v2/classes.rb', line 362 def recordings @recordings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
369 370 371 372 |
# File 'lib/google/apis/meet_v2/classes.rb', line 369 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @recordings = args[:recordings] if args.key?(:recordings) end |