Class: Google::Apis::MeetV2::ListSmartNotesResponse
- Inherits:
-
Object
- Object
- Google::Apis::MeetV2::ListSmartNotesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/meet_v2/classes.rb,
lib/google/apis/meet_v2/representations.rb,
lib/google/apis/meet_v2/representations.rb
Overview
Response for ListSmartNotes method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Token to be circulated back for further List call if current List doesn't include all the smart notes.
-
#smart_notes ⇒ Array<Google::Apis::MeetV2::SmartNote>
List of smart notes in one page.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListSmartNotesResponse
constructor
A new instance of ListSmartNotesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListSmartNotesResponse
Returns a new instance of ListSmartNotesResponse.
390 391 392 |
# File 'lib/google/apis/meet_v2/classes.rb', line 390 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Token to be circulated back for further List call if current List doesn't
include all the smart notes. Unset if all smart notes are returned.
Corresponds to the JSON property nextPageToken
383 384 385 |
# File 'lib/google/apis/meet_v2/classes.rb', line 383 def next_page_token @next_page_token end |
#smart_notes ⇒ Array<Google::Apis::MeetV2::SmartNote>
List of smart notes in one page.
Corresponds to the JSON property smartNotes
388 389 390 |
# File 'lib/google/apis/meet_v2/classes.rb', line 388 def smart_notes @smart_notes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
395 396 397 398 |
# File 'lib/google/apis/meet_v2/classes.rb', line 395 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @smart_notes = args[:smart_notes] if args.key?(:smart_notes) end |