Class: Google::Apis::MeetV2::ListTranscriptEntriesResponse
- Inherits:
-
Object
- Object
- Google::Apis::MeetV2::ListTranscriptEntriesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/meet_v2/classes.rb,
lib/google/apis/meet_v2/representations.rb,
lib/google/apis/meet_v2/representations.rb
Overview
Response for ListTranscriptEntries method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Token to be circulated back for further List call if current List doesn't include all the transcript entries.
-
#transcript_entries ⇒ Array<Google::Apis::MeetV2::TranscriptEntry>
List of TranscriptEntries in one page.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListTranscriptEntriesResponse
constructor
A new instance of ListTranscriptEntriesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListTranscriptEntriesResponse
Returns a new instance of ListTranscriptEntriesResponse.
416 417 418 |
# File 'lib/google/apis/meet_v2/classes.rb', line 416 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Token to be circulated back for further List call if current List doesn't
include all the transcript entries. Unset if all entries are returned.
Corresponds to the JSON property nextPageToken
409 410 411 |
# File 'lib/google/apis/meet_v2/classes.rb', line 409 def next_page_token @next_page_token end |
#transcript_entries ⇒ Array<Google::Apis::MeetV2::TranscriptEntry>
List of TranscriptEntries in one page.
Corresponds to the JSON property transcriptEntries
414 415 416 |
# File 'lib/google/apis/meet_v2/classes.rb', line 414 def transcript_entries @transcript_entries end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
421 422 423 424 |
# File 'lib/google/apis/meet_v2/classes.rb', line 421 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @transcript_entries = args[:transcript_entries] if args.key?(:transcript_entries) end |