Class: Google::Apis::MeetV2::ListTranscriptsResponse
- Inherits:
-
Object
- Object
- Google::Apis::MeetV2::ListTranscriptsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/meet_v2/classes.rb,
lib/google/apis/meet_v2/representations.rb,
lib/google/apis/meet_v2/representations.rb
Overview
Response for ListTranscripts method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Token to be circulated back for further List call if current List doesn't include all the transcripts.
-
#transcripts ⇒ Array<Google::Apis::MeetV2::Transcript>
List of transcripts in one page.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListTranscriptsResponse
constructor
A new instance of ListTranscriptsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListTranscriptsResponse
Returns a new instance of ListTranscriptsResponse.
442 443 444 |
# File 'lib/google/apis/meet_v2/classes.rb', line 442 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Token to be circulated back for further List call if current List doesn't
include all the transcripts. Unset if all transcripts are returned.
Corresponds to the JSON property nextPageToken
435 436 437 |
# File 'lib/google/apis/meet_v2/classes.rb', line 435 def next_page_token @next_page_token end |
#transcripts ⇒ Array<Google::Apis::MeetV2::Transcript>
List of transcripts in one page.
Corresponds to the JSON property transcripts
440 441 442 |
# File 'lib/google/apis/meet_v2/classes.rb', line 440 def transcripts @transcripts end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
447 448 449 450 |
# File 'lib/google/apis/meet_v2/classes.rb', line 447 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @transcripts = args[:transcripts] if args.key?(:transcripts) end |