Class: Google::Apis::MeetV2::MeetService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::MeetV2::MeetService
- Defined in:
- lib/google/apis/meet_v2/service.rb
Overview
Google Meet API
Create and manage meetings in Google Meet.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://meet.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#create_space(space_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MeetV2::Space
Creates a space.
-
#end_space_active_conference(name, end_active_conference_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MeetV2::Empty
Ends an active conference (if there's one).
-
#get_conference_record(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MeetV2::ConferenceRecord
Gets a conference record by conference ID.
-
#get_conference_record_participant(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MeetV2::Participant
Gets a participant by participant ID.
-
#get_conference_record_participant_participant_session(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MeetV2::ParticipantSession
Gets a participant session by participant session ID.
-
#get_conference_record_recording(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MeetV2::Recording
Gets a recording by recording ID.
-
#get_conference_record_smart_note(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MeetV2::SmartNote
Gets smart notes by smart note ID.
-
#get_conference_record_transcript(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MeetV2::Transcript
Gets a transcript by transcript ID.
-
#get_conference_record_transcript_entry(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MeetV2::TranscriptEntry
Gets a
TranscriptEntryresource by entry ID. -
#get_space(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MeetV2::Space
Gets details about a meeting space.
-
#initialize ⇒ MeetService
constructor
A new instance of MeetService.
-
#list_conference_record_participant_participant_sessions(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MeetV2::ListParticipantSessionsResponse
Lists the participant sessions of a participant in a conference record.
-
#list_conference_record_participants(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MeetV2::ListParticipantsResponse
Lists the participants in a conference record.
-
#list_conference_record_recordings(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MeetV2::ListRecordingsResponse
Lists the recording resources from the conference record.
-
#list_conference_record_smart_notes(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MeetV2::ListSmartNotesResponse
Lists the set of smart notes from the conference record.
-
#list_conference_record_transcript_entries(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MeetV2::ListTranscriptEntriesResponse
Lists the structured transcript entries per transcript.
-
#list_conference_record_transcripts(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MeetV2::ListTranscriptsResponse
Lists the set of transcripts from the conference record.
-
#list_conference_records(filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MeetV2::ListConferenceRecordsResponse
Lists the conference records.
-
#patch_space(name, space_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MeetV2::Space
Updates details about a meeting space.
Constructor Details
#initialize ⇒ MeetService
Returns a new instance of MeetService.
47 48 49 50 51 52 |
# File 'lib/google/apis/meet_v2/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-meet_v2', client_version: Google::Apis::MeetV2::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/meet_v2/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/meet_v2/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#create_space(space_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MeetV2::Space
Creates a space.
595 596 597 598 599 600 601 602 603 604 |
# File 'lib/google/apis/meet_v2/service.rb', line 595 def create_space(space_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2/spaces', ) command.request_representation = Google::Apis::MeetV2::Space::Representation command.request_object = space_object command.response_representation = Google::Apis::MeetV2::Space::Representation command.response_class = Google::Apis::MeetV2::Space command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#end_space_active_conference(name, end_active_conference_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MeetV2::Empty
Ends an active conference (if there's one). For an example, see End active conference.
633 634 635 636 637 638 639 640 641 642 643 |
# File 'lib/google/apis/meet_v2/service.rb', line 633 def end_space_active_conference(name, end_active_conference_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2/{+name}:endActiveConference', ) command.request_representation = Google::Apis::MeetV2::EndActiveConferenceRequest::Representation command.request_object = end_active_conference_request_object command.response_representation = Google::Apis::MeetV2::Empty::Representation command.response_class = Google::Apis::MeetV2::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_conference_record(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MeetV2::ConferenceRecord
Gets a conference record by conference ID.
74 75 76 77 78 79 80 81 82 |
# File 'lib/google/apis/meet_v2/service.rb', line 74 def get_conference_record(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+name}', ) command.response_representation = Google::Apis::MeetV2::ConferenceRecord::Representation command.response_class = Google::Apis::MeetV2::ConferenceRecord command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_conference_record_participant(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MeetV2::Participant
Gets a participant by participant ID.
149 150 151 152 153 154 155 156 157 |
# File 'lib/google/apis/meet_v2/service.rb', line 149 def get_conference_record_participant(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+name}', ) command.response_representation = Google::Apis::MeetV2::Participant::Representation command.response_class = Google::Apis::MeetV2::Participant command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_conference_record_participant_participant_session(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MeetV2::ParticipantSession
Gets a participant session by participant session ID.
227 228 229 230 231 232 233 234 235 |
# File 'lib/google/apis/meet_v2/service.rb', line 227 def get_conference_record_participant_participant_session(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+name}', ) command.response_representation = Google::Apis::MeetV2::ParticipantSession::Representation command.response_class = Google::Apis::MeetV2::ParticipantSession command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_conference_record_recording(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MeetV2::Recording
Gets a recording by recording ID.
307 308 309 310 311 312 313 314 315 |
# File 'lib/google/apis/meet_v2/service.rb', line 307 def get_conference_record_recording(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+name}', ) command.response_representation = Google::Apis::MeetV2::Recording::Representation command.response_class = Google::Apis::MeetV2::Recording command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_conference_record_smart_note(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MeetV2::SmartNote
Gets smart notes by smart note ID.
378 379 380 381 382 383 384 385 386 |
# File 'lib/google/apis/meet_v2/service.rb', line 378 def get_conference_record_smart_note(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+name}', ) command.response_representation = Google::Apis::MeetV2::SmartNote::Representation command.response_class = Google::Apis::MeetV2::SmartNote command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_conference_record_transcript(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MeetV2::Transcript
Gets a transcript by transcript ID.
448 449 450 451 452 453 454 455 456 |
# File 'lib/google/apis/meet_v2/service.rb', line 448 def get_conference_record_transcript(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+name}', ) command.response_representation = Google::Apis::MeetV2::Transcript::Representation command.response_class = Google::Apis::MeetV2::Transcript command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_conference_record_transcript_entry(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MeetV2::TranscriptEntry
Gets a TranscriptEntry resource by entry ID. Note: The transcript entries
returned by the Google Meet API might not match the transcription found in the
Google Docs transcript file. This can occur when 1) we have interleaved
speakers within milliseconds, or 2) the Google Docs transcript file is
modified after generation.
522 523 524 525 526 527 528 529 530 |
# File 'lib/google/apis/meet_v2/service.rb', line 522 def get_conference_record_transcript_entry(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+name}', ) command.response_representation = Google::Apis::MeetV2::TranscriptEntry::Representation command.response_class = Google::Apis::MeetV2::TranscriptEntry command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_space(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MeetV2::Space
Gets details about a meeting space. For an example, see Get a meeting space.
678 679 680 681 682 683 684 685 686 |
# File 'lib/google/apis/meet_v2/service.rb', line 678 def get_space(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+name}', ) command.response_representation = Google::Apis::MeetV2::Space::Representation command.response_class = Google::Apis::MeetV2::Space command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_conference_record_participant_participant_sessions(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MeetV2::ListParticipantSessionsResponse
Lists the participant sessions of a participant in a conference record. By
default, ordered by join time and in descending order. This API supports
fields as standard parameters like every other API. However, when the fields
request parameter is omitted this API defaults to 'participantsessions/*,
next_page_token'.
274 275 276 277 278 279 280 281 282 283 284 285 |
# File 'lib/google/apis/meet_v2/service.rb', line 274 def list_conference_record_participant_participant_sessions(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+parent}/participantSessions', ) command.response_representation = Google::Apis::MeetV2::ListParticipantSessionsResponse::Representation command.response_class = Google::Apis::MeetV2::ListParticipantSessionsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_conference_record_participants(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MeetV2::ListParticipantsResponse
Lists the participants in a conference record. By default, ordered by join
time and in descending order. This API supports fields as standard
parameters like every other API. However, when the fields request parameter
is omitted, this API defaults to 'participants/*, next_page_token'.
194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/google/apis/meet_v2/service.rb', line 194 def list_conference_record_participants(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+parent}/participants', ) command.response_representation = Google::Apis::MeetV2::ListParticipantsResponse::Representation command.response_class = Google::Apis::MeetV2::ListParticipantsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_conference_record_recordings(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MeetV2::ListRecordingsResponse
Lists the recording resources from the conference record. By default, ordered by start time and in ascending order.
345 346 347 348 349 350 351 352 353 354 355 |
# File 'lib/google/apis/meet_v2/service.rb', line 345 def list_conference_record_recordings(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+parent}/recordings', ) command.response_representation = Google::Apis::MeetV2::ListRecordingsResponse::Representation command.response_class = Google::Apis::MeetV2::ListRecordingsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_conference_record_smart_notes(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MeetV2::ListSmartNotesResponse
Lists the set of smart notes from the conference record. By default, ordered by start time and in ascending order.
416 417 418 419 420 421 422 423 424 425 426 |
# File 'lib/google/apis/meet_v2/service.rb', line 416 def list_conference_record_smart_notes(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+parent}/smartNotes', ) command.response_representation = Google::Apis::MeetV2::ListSmartNotesResponse::Representation command.response_class = Google::Apis::MeetV2::ListSmartNotesResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_conference_record_transcript_entries(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MeetV2::ListTranscriptEntriesResponse
Lists the structured transcript entries per transcript. By default, ordered by start time and in ascending order. Note: The transcript entries returned by the Google Meet API might not match the transcription found in the Google Docs transcript file. This can occur when 1) we have interleaved speakers within milliseconds, or 2) the Google Docs transcript file is modified after generation.
564 565 566 567 568 569 570 571 572 573 574 |
# File 'lib/google/apis/meet_v2/service.rb', line 564 def list_conference_record_transcript_entries(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+parent}/entries', ) command.response_representation = Google::Apis::MeetV2::ListTranscriptEntriesResponse::Representation command.response_class = Google::Apis::MeetV2::ListTranscriptEntriesResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_conference_record_transcripts(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MeetV2::ListTranscriptsResponse
Lists the set of transcripts from the conference record. By default, ordered by start time and in ascending order.
486 487 488 489 490 491 492 493 494 495 496 |
# File 'lib/google/apis/meet_v2/service.rb', line 486 def list_conference_record_transcripts(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+parent}/transcripts', ) command.response_representation = Google::Apis::MeetV2::ListTranscriptsResponse::Representation command.response_class = Google::Apis::MeetV2::ListTranscriptsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_conference_records(filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MeetV2::ListConferenceRecordsResponse
Lists the conference records. By default, ordered by start time and in descending order.
117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/google/apis/meet_v2/service.rb', line 117 def list_conference_records(filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/conferenceRecords', ) command.response_representation = Google::Apis::MeetV2::ListConferenceRecordsResponse::Representation command.response_class = Google::Apis::MeetV2::ListConferenceRecordsResponse command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_space(name, space_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::MeetV2::Space
Updates details about a meeting space. For an example, see Update a meeting space.
721 722 723 724 725 726 727 728 729 730 731 732 |
# File 'lib/google/apis/meet_v2/service.rb', line 721 def patch_space(name, space_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v2/{+name}', ) command.request_representation = Google::Apis::MeetV2::Space::Representation command.request_object = space_object command.response_representation = Google::Apis::MeetV2::Space::Representation command.response_class = Google::Apis::MeetV2::Space command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |