Class: Google::Apis::MeetV2::ModerationRestrictions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/meet_v2/classes.rb,
lib/google/apis/meet_v2/representations.rb,
lib/google/apis/meet_v2/representations.rb

Overview

Defines restrictions for features when the meeting is moderated.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ModerationRestrictions

Returns a new instance of ModerationRestrictions.



477
478
479
# File 'lib/google/apis/meet_v2/classes.rb', line 477

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chat_restrictionString

Defines who has permission to send chat messages in the meeting space. Corresponds to the JSON property chatRestriction

Returns:

  • (String)


460
461
462
# File 'lib/google/apis/meet_v2/classes.rb', line 460

def chat_restriction
  @chat_restriction
end

#default_join_as_viewer_typeString

Defines whether to restrict the default role assigned to users as viewer. Corresponds to the JSON property defaultJoinAsViewerType

Returns:

  • (String)


465
466
467
# File 'lib/google/apis/meet_v2/classes.rb', line 465

def default_join_as_viewer_type
  @default_join_as_viewer_type
end

#present_restrictionString

Defines who has permission to share their screen in the meeting space. Corresponds to the JSON property presentRestriction

Returns:

  • (String)


470
471
472
# File 'lib/google/apis/meet_v2/classes.rb', line 470

def present_restriction
  @present_restriction
end

#reaction_restrictionString

Defines who has permission to send reactions in the meeting space. Corresponds to the JSON property reactionRestriction

Returns:

  • (String)


475
476
477
# File 'lib/google/apis/meet_v2/classes.rb', line 475

def reaction_restriction
  @reaction_restriction
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



482
483
484
485
486
487
# File 'lib/google/apis/meet_v2/classes.rb', line 482

def update!(**args)
  @chat_restriction = args[:chat_restriction] if args.key?(:chat_restriction)
  @default_join_as_viewer_type = args[:default_join_as_viewer_type] if args.key?(:default_join_as_viewer_type)
  @present_restriction = args[:present_restriction] if args.key?(:present_restriction)
  @reaction_restriction = args[:reaction_restriction] if args.key?(:reaction_restriction)
end