Class: Google::Apis::MeetV2::ParticipantSession

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/meet_v2/classes.rb,
lib/google/apis/meet_v2/representations.rb,
lib/google/apis/meet_v2/representations.rb

Overview

Refers to each unique join or leave session when a user joins a conference from a device. Note that any time a user joins the conference a new unique ID is assigned. That means if a user joins a space multiple times from the same device, they're assigned different IDs, and are also be treated as different participant sessions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ParticipantSession

Returns a new instance of ParticipantSession.



565
566
567
# File 'lib/google/apis/meet_v2/classes.rb', line 565

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_timeString

Output only. Timestamp when the user session ends. Unset if the user session hasn’t ended. Corresponds to the JSON property endTime

Returns:

  • (String)


553
554
555
# File 'lib/google/apis/meet_v2/classes.rb', line 553

def end_time
  @end_time
end

#nameString

Identifier. Session id. Corresponds to the JSON property name

Returns:

  • (String)


558
559
560
# File 'lib/google/apis/meet_v2/classes.rb', line 558

def name
  @name
end

#start_timeString

Output only. Timestamp when the user session starts. Corresponds to the JSON property startTime

Returns:

  • (String)


563
564
565
# File 'lib/google/apis/meet_v2/classes.rb', line 563

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



570
571
572
573
574
# File 'lib/google/apis/meet_v2/classes.rb', line 570

def update!(**args)
  @end_time = args[:end_time] if args.key?(:end_time)
  @name = args[:name] if args.key?(:name)
  @start_time = args[:start_time] if args.key?(:start_time)
end