Class: Google::Apis::MeetV2::RecordingConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/meet_v2/classes.rb,
lib/google/apis/meet_v2/representations.rb,
lib/google/apis/meet_v2/representations.rb

Overview

Configuration related to recording in a meeting space.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RecordingConfig

Returns a new instance of RecordingConfig.



695
696
697
# File 'lib/google/apis/meet_v2/classes.rb', line 695

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_recording_generationString

Defines whether a meeting space is automatically recorded when someone with the privilege to record joins the meeting. Corresponds to the JSON property autoRecordingGeneration

Returns:

  • (String)


693
694
695
# File 'lib/google/apis/meet_v2/classes.rb', line 693

def auto_recording_generation
  @auto_recording_generation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



700
701
702
# File 'lib/google/apis/meet_v2/classes.rb', line 700

def update!(**args)
  @auto_recording_generation = args[:auto_recording_generation] if args.key?(:auto_recording_generation)
end