Class: Google::Apis::MeetV2::SmartNote
- Inherits:
-
Object
- Object
- Google::Apis::MeetV2::SmartNote
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/meet_v2/classes.rb,
lib/google/apis/meet_v2/representations.rb,
lib/google/apis/meet_v2/representations.rb
Overview
Metadata for a smart note generated from a conference. It refers to the notes generated from Take Notes with Gemini during the conference.
Instance Attribute Summary collapse
-
#docs_destination ⇒ Google::Apis::MeetV2::DocsDestination
Google Docs location where the transcript file is saved.
-
#end_time ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SmartNote
constructor
A new instance of SmartNote.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SmartNote
Returns a new instance of SmartNote.
771 772 773 |
# File 'lib/google/apis/meet_v2/classes.rb', line 771 def initialize(**args) update!(**args) end |
Instance Attribute Details
#docs_destination ⇒ Google::Apis::MeetV2::DocsDestination
Google Docs location where the transcript file is saved.
Corresponds to the JSON property docsDestination
746 747 748 |
# File 'lib/google/apis/meet_v2/classes.rb', line 746 def docs_destination @docs_destination end |
#end_time ⇒ String
Output only. Timestamp when the smart notes stopped.
Corresponds to the JSON property endTime
751 752 753 |
# File 'lib/google/apis/meet_v2/classes.rb', line 751 def end_time @end_time end |
#name ⇒ String
Output only. Identifier. Resource name of the smart notes. Format:
conferenceRecords/conference_record/smartNotes/smart_note, where
smart_note`is a 1:1 mapping to each unique smart notes session of the
conference.
Corresponds to the JSON propertyname`
759 760 761 |
# File 'lib/google/apis/meet_v2/classes.rb', line 759 def name @name end |
#start_time ⇒ String
Output only. Timestamp when the smart notes started.
Corresponds to the JSON property startTime
764 765 766 |
# File 'lib/google/apis/meet_v2/classes.rb', line 764 def start_time @start_time end |
#state ⇒ String
Output only. Current state.
Corresponds to the JSON property state
769 770 771 |
# File 'lib/google/apis/meet_v2/classes.rb', line 769 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
776 777 778 779 780 781 782 |
# File 'lib/google/apis/meet_v2/classes.rb', line 776 def update!(**args) @docs_destination = args[:docs_destination] if args.key?(:docs_destination) @end_time = args[:end_time] if args.key?(:end_time) @name = args[:name] if args.key?(:name) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) end |