Class: Google::Apis::MeetV2::SmartNotesConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/meet_v2/classes.rb,
lib/google/apis/meet_v2/representations.rb,
lib/google/apis/meet_v2/representations.rb

Overview

Configuration related to smart notes in a meeting space. For more information about smart notes, see "Take notes for me" in Google Meet.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SmartNotesConfig

Returns a new instance of SmartNotesConfig.



798
799
800
# File 'lib/google/apis/meet_v2/classes.rb', line 798

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_smart_notes_generationString

Defines whether to automatically generate a summary and recap of the meeting for all invitees in the organization when someone with the privilege to enable smart notes joins the meeting. Corresponds to the JSON property autoSmartNotesGeneration

Returns:

  • (String)


796
797
798
# File 'lib/google/apis/meet_v2/classes.rb', line 796

def auto_smart_notes_generation
  @auto_smart_notes_generation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



803
804
805
# File 'lib/google/apis/meet_v2/classes.rb', line 803

def update!(**args)
  @auto_smart_notes_generation = args[:auto_smart_notes_generation] if args.key?(:auto_smart_notes_generation)
end