Class: Google::Apis::MeetV2::Space
- Inherits:
-
Object
- Object
- Google::Apis::MeetV2::Space
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/meet_v2/classes.rb,
lib/google/apis/meet_v2/representations.rb,
lib/google/apis/meet_v2/representations.rb
Overview
Virtual place where conferences are held. Only one active conference can be held in one space at any given time.
Instance Attribute Summary collapse
-
#active_conference ⇒ Google::Apis::MeetV2::ActiveConference
Active conference.
-
#config ⇒ Google::Apis::MeetV2::SpaceConfig
The configuration pertaining to a meeting space.
-
#gateway_sip_access ⇒ Array<Google::Apis::MeetV2::GatewaySipAccess>
Output only.
-
#meeting_code ⇒ String
Output only.
-
#meeting_uri ⇒ String
Output only.
-
#name ⇒ String
Immutable.
-
#phone_access ⇒ Array<Google::Apis::MeetV2::PhoneAccess>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Space
constructor
A new instance of Space.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Space
Returns a new instance of Space.
858 859 860 |
# File 'lib/google/apis/meet_v2/classes.rb', line 858 def initialize(**args) update!(**args) end |
Instance Attribute Details
#active_conference ⇒ Google::Apis::MeetV2::ActiveConference
Active conference.
Corresponds to the JSON property activeConference
816 817 818 |
# File 'lib/google/apis/meet_v2/classes.rb', line 816 def active_conference @active_conference end |
#config ⇒ Google::Apis::MeetV2::SpaceConfig
The configuration pertaining to a meeting space.
Corresponds to the JSON property config
821 822 823 |
# File 'lib/google/apis/meet_v2/classes.rb', line 821 def config @config end |
#gateway_sip_access ⇒ Array<Google::Apis::MeetV2::GatewaySipAccess>
Output only. The SIP-based access methods that can be used to join the
conference. Can be empty.
Corresponds to the JSON property gatewaySipAccess
827 828 829 |
# File 'lib/google/apis/meet_v2/classes.rb', line 827 def gateway_sip_access @gateway_sip_access end |
#meeting_code ⇒ String
Output only. Type friendly unique string used to join the meeting. Format: [a-
z]+-[a-z]+-[a-z]+. For example, abc-mnop-xyz. The maximum length is 128
characters. Can only be used as an alias of the space name to get the space.
Corresponds to the JSON property meetingCode
834 835 836 |
# File 'lib/google/apis/meet_v2/classes.rb', line 834 def meeting_code @meeting_code end |
#meeting_uri ⇒ String
Output only. URI used to join meetings consisting of https://meet.google.com/
followed by the meeting_code. For example, https://meet.google.com/abc-
mnop-xyz.
Corresponds to the JSON property meetingUri
841 842 843 |
# File 'lib/google/apis/meet_v2/classes.rb', line 841 def meeting_uri @meeting_uri end |
#name ⇒ String
Immutable. Resource name of the space. Format: spaces/space.space`is
the resource identifier for the space. It's a unique, server-generated ID and
is case sensitive. For example,jQCFfuBOdN5z. For more information, see [How
Meet identifies a meeting space](https://developers.google.com/workspace/meet/
api/guides/meeting-spaces#identify-meeting-space).
Corresponds to the JSON propertyname`
850 851 852 |
# File 'lib/google/apis/meet_v2/classes.rb', line 850 def name @name end |
#phone_access ⇒ Array<Google::Apis::MeetV2::PhoneAccess>
Output only. All regional phone access methods for this meeting space. Can be
empty.
Corresponds to the JSON property phoneAccess
856 857 858 |
# File 'lib/google/apis/meet_v2/classes.rb', line 856 def phone_access @phone_access end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
863 864 865 866 867 868 869 870 871 |
# File 'lib/google/apis/meet_v2/classes.rb', line 863 def update!(**args) @active_conference = args[:active_conference] if args.key?(:active_conference) @config = args[:config] if args.key?(:config) @gateway_sip_access = args[:gateway_sip_access] if args.key?(:gateway_sip_access) @meeting_code = args[:meeting_code] if args.key?(:meeting_code) @meeting_uri = args[:meeting_uri] if args.key?(:meeting_uri) @name = args[:name] if args.key?(:name) @phone_access = args[:phone_access] if args.key?(:phone_access) end |