Class: Google::Apis::MeetV2::Transcript

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/meet_v2/classes.rb,
lib/google/apis/meet_v2/representations.rb,
lib/google/apis/meet_v2/representations.rb

Overview

Metadata for a transcript generated from a conference. It refers to the ASR ( Automatic Speech Recognition) result of user's speech during the conference.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Transcript

Returns a new instance of Transcript.



960
961
962
# File 'lib/google/apis/meet_v2/classes.rb', line 960

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#docs_destinationGoogle::Apis::MeetV2::DocsDestination

Google Docs location where the transcript file is saved. Corresponds to the JSON property docsDestination



936
937
938
# File 'lib/google/apis/meet_v2/classes.rb', line 936

def docs_destination
  @docs_destination
end

#end_timeString

Output only. Timestamp when the transcript stopped. Corresponds to the JSON property endTime

Returns:

  • (String)


941
942
943
# File 'lib/google/apis/meet_v2/classes.rb', line 941

def end_time
  @end_time
end

#nameString

Output only. Resource name of the transcript. Format: conferenceRecords/ conference_record/transcripts/transcript, wheretranscript`is a 1:1 mapping to each unique transcription session of the conference. Corresponds to the JSON propertyname`

Returns:

  • (String)


948
949
950
# File 'lib/google/apis/meet_v2/classes.rb', line 948

def name
  @name
end

#start_timeString

Output only. Timestamp when the transcript started. Corresponds to the JSON property startTime

Returns:

  • (String)


953
954
955
# File 'lib/google/apis/meet_v2/classes.rb', line 953

def start_time
  @start_time
end

#stateString

Output only. Current state. Corresponds to the JSON property state

Returns:

  • (String)


958
959
960
# File 'lib/google/apis/meet_v2/classes.rb', line 958

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



965
966
967
968
969
970
971
# File 'lib/google/apis/meet_v2/classes.rb', line 965

def update!(**args)
  @docs_destination = args[:docs_destination] if args.key?(:docs_destination)
  @end_time = args[:end_time] if args.key?(:end_time)
  @name = args[:name] if args.key?(:name)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
end