Class: Google::Apis::MeetV2::TranscriptionConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/meet_v2/classes.rb,
lib/google/apis/meet_v2/representations.rb,
lib/google/apis/meet_v2/representations.rb

Overview

Configuration related to transcription in a meeting space.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TranscriptionConfig

Returns a new instance of TranscriptionConfig.



1036
1037
1038
# File 'lib/google/apis/meet_v2/classes.rb', line 1036

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_transcription_generationString

Defines whether the content of a meeting is automatically transcribed when someone with the privilege to transcribe joins the meeting. Corresponds to the JSON property autoTranscriptionGeneration

Returns:

  • (String)


1034
1035
1036
# File 'lib/google/apis/meet_v2/classes.rb', line 1034

def auto_transcription_generation
  @auto_transcription_generation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1041
1042
1043
# File 'lib/google/apis/meet_v2/classes.rb', line 1041

def update!(**args)
  @auto_transcription_generation = args[:auto_transcription_generation] if args.key?(:auto_transcription_generation)
end