Class: Google::Apis::MeetV2::GatewaySipAccess
- Inherits:
-
Object
- Object
- Google::Apis::MeetV2::GatewaySipAccess
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/meet_v2/classes.rb,
lib/google/apis/meet_v2/representations.rb,
lib/google/apis/meet_v2/representations.rb
Overview
Details how to join the conference through a SIP gateway.
Instance Attribute Summary collapse
-
#sip_access_code ⇒ String
The permanent numeric code for manual entry on specially configured devices.
-
#uri ⇒ String
The Session Initiation Protocol (SIP) URI the conference can be reached through.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GatewaySipAccess
constructor
A new instance of GatewaySipAccess.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GatewaySipAccess
Returns a new instance of GatewaySipAccess.
252 253 254 |
# File 'lib/google/apis/meet_v2/classes.rb', line 252 def initialize(**args) update!(**args) end |
Instance Attribute Details
#sip_access_code ⇒ String
The permanent numeric code for manual entry on specially configured devices.
Corresponds to the JSON property sipAccessCode
240 241 242 |
# File 'lib/google/apis/meet_v2/classes.rb', line 240 def sip_access_code @sip_access_code end |
#uri ⇒ String
The Session Initiation Protocol (SIP) URI the conference can be reached through. The string is in one of these formats: * "sip:USER_ID@GATEWAY_ADDRESS"
- "sips:USER_ID@GATEWAY_ADDRESS" where USER_ID is the 13-digit universal pin (
with the future option to support using a Meet meeting code as well), and
GATEWAY_ADDRESS is a valid address to be resolved using a DNS SRV lookup, or a
dotted quad.
Corresponds to the JSON property
uri
250 251 252 |
# File 'lib/google/apis/meet_v2/classes.rb', line 250 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
257 258 259 260 |
# File 'lib/google/apis/meet_v2/classes.rb', line 257 def update!(**args) @sip_access_code = args[:sip_access_code] if args.key?(:sip_access_code) @uri = args[:uri] if args.key?(:uri) end |