Class: Google::Apis::MeetV2::GatewaySipAccess

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/meet_v2/classes.rb,
lib/google/apis/meet_v2/representations.rb,
lib/google/apis/meet_v2/representations.rb

Overview

Details how to join the conference via a SIP gateway.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GatewaySipAccess

Returns a new instance of GatewaySipAccess.



249
250
251
# File 'lib/google/apis/meet_v2/classes.rb', line 249

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#sip_access_codeString

Permanent numeric code for manual entry on specially configured devices. Corresponds to the JSON property sipAccessCode

Returns:

  • (String)


240
241
242
# File 'lib/google/apis/meet_v2/classes.rb', line 240

def sip_access_code
  @sip_access_code
end

#uriString

The SIP URI the conference can be reached through. The string is on one of the formats: "sip:@" "sips:@" where currently is the 13-digit universal pin, and is a valid address to be resolved using a DNS SRV lookup, or a dotted quad. Corresponds to the JSON property uri

Returns:

  • (String)


247
248
249
# File 'lib/google/apis/meet_v2/classes.rb', line 247

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



254
255
256
257
# File 'lib/google/apis/meet_v2/classes.rb', line 254

def update!(**args)
  @sip_access_code = args[:sip_access_code] if args.key?(:sip_access_code)
  @uri = args[:uri] if args.key?(:uri)
end