Class: Google::Apis::MeetV2::ListConferenceRecordsResponse
- Inherits:
-
Object
- Object
- Google::Apis::MeetV2::ListConferenceRecordsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/meet_v2/classes.rb,
lib/google/apis/meet_v2/representations.rb,
lib/google/apis/meet_v2/representations.rb
Overview
Response of ListConferenceRecords method.
Instance Attribute Summary collapse
-
#conference_records ⇒ Array<Google::Apis::MeetV2::ConferenceRecord>
List of conferences in one page.
-
#next_page_token ⇒ String
Token to be circulated back for further List call if current List does NOT include all the Conferences.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListConferenceRecordsResponse
constructor
A new instance of ListConferenceRecordsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListConferenceRecordsResponse
Returns a new instance of ListConferenceRecordsResponse.
275 276 277 |
# File 'lib/google/apis/meet_v2/classes.rb', line 275 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conference_records ⇒ Array<Google::Apis::MeetV2::ConferenceRecord>
List of conferences in one page.
Corresponds to the JSON property conferenceRecords
267 268 269 |
# File 'lib/google/apis/meet_v2/classes.rb', line 267 def conference_records @conference_records end |
#next_page_token ⇒ String
Token to be circulated back for further List call if current List does NOT
include all the Conferences. Unset if all conferences have been returned.
Corresponds to the JSON property nextPageToken
273 274 275 |
# File 'lib/google/apis/meet_v2/classes.rb', line 273 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
280 281 282 283 |
# File 'lib/google/apis/meet_v2/classes.rb', line 280 def update!(**args) @conference_records = args[:conference_records] if args.key?(:conference_records) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |