Class: Google::Apis::MeetV2::ListParticipantSessionsResponse
- Inherits:
-
Object
- Object
- Google::Apis::MeetV2::ListParticipantSessionsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/meet_v2/classes.rb,
lib/google/apis/meet_v2/representations.rb,
lib/google/apis/meet_v2/representations.rb
Overview
Response of ListParticipants method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Token to be circulated back for further List call if current List doesn't include all the participants.
-
#participant_sessions ⇒ Array<Google::Apis::MeetV2::ParticipantSession>
List of participants in one page.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListParticipantSessionsResponse
constructor
A new instance of ListParticipantSessionsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListParticipantSessionsResponse
Returns a new instance of ListParticipantSessionsResponse.
301 302 303 |
# File 'lib/google/apis/meet_v2/classes.rb', line 301 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Token to be circulated back for further List call if current List doesn't
include all the participants. Unset if all participants are returned.
Corresponds to the JSON property nextPageToken
294 295 296 |
# File 'lib/google/apis/meet_v2/classes.rb', line 294 def next_page_token @next_page_token end |
#participant_sessions ⇒ Array<Google::Apis::MeetV2::ParticipantSession>
List of participants in one page.
Corresponds to the JSON property participantSessions
299 300 301 |
# File 'lib/google/apis/meet_v2/classes.rb', line 299 def participant_sessions @participant_sessions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
306 307 308 309 |
# File 'lib/google/apis/meet_v2/classes.rb', line 306 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @participant_sessions = args[:participant_sessions] if args.key?(:participant_sessions) end |