Class: Google::Apis::MeetV2::ListParticipantsResponse
- Inherits:
-
Object
- Object
- Google::Apis::MeetV2::ListParticipantsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/meet_v2/classes.rb,
lib/google/apis/meet_v2/representations.rb,
lib/google/apis/meet_v2/representations.rb
Overview
Response of ListParticipants method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Token to be circulated back for further List call if current List doesn't include all the participants.
-
#participants ⇒ Array<Google::Apis::MeetV2::Participant>
List of participants in one page.
-
#total_size ⇒ Fixnum
Total, exact number of
participants.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListParticipantsResponse
constructor
A new instance of ListParticipantsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListParticipantsResponse
Returns a new instance of ListParticipantsResponse.
334 335 336 |
# File 'lib/google/apis/meet_v2/classes.rb', line 334 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Token to be circulated back for further List call if current List doesn't
include all the participants. Unset if all participants are returned.
Corresponds to the JSON property nextPageToken
320 321 322 |
# File 'lib/google/apis/meet_v2/classes.rb', line 320 def next_page_token @next_page_token end |
#participants ⇒ Array<Google::Apis::MeetV2::Participant>
List of participants in one page.
Corresponds to the JSON property participants
325 326 327 |
# File 'lib/google/apis/meet_v2/classes.rb', line 325 def participants @participants end |
#total_size ⇒ Fixnum
Total, exact number of participants. By default, this field isn't included
in the response. Set the field mask in SystemParameterContext to receive this field in the response.
Corresponds to the JSON property totalSize
332 333 334 |
# File 'lib/google/apis/meet_v2/classes.rb', line 332 def total_size @total_size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
339 340 341 342 343 |
# File 'lib/google/apis/meet_v2/classes.rb', line 339 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @participants = args[:participants] if args.key?(:participants) @total_size = args[:total_size] if args.key?(:total_size) end |