Class: Google::Apis::MeetV2::ListRecordingsResponse
- Inherits:
-
Object
- Object
- Google::Apis::MeetV2::ListRecordingsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/meet_v2/classes.rb,
lib/google/apis/meet_v2/representations.rb,
lib/google/apis/meet_v2/representations.rb
Overview
Response for ListRecordings method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Token to be circulated back for further List call if current List doesn't include all the recordings.
-
#recordings ⇒ Array<Google::Apis::MeetV2::Recording>
List of recordings in one page.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListRecordingsResponse
constructor
A new instance of ListRecordingsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListRecordingsResponse
Returns a new instance of ListRecordingsResponse.
361 362 363 |
# File 'lib/google/apis/meet_v2/classes.rb', line 361 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Token to be circulated back for further List call if current List doesn't
include all the recordings. Unset if all recordings are returned.
Corresponds to the JSON property nextPageToken
354 355 356 |
# File 'lib/google/apis/meet_v2/classes.rb', line 354 def next_page_token @next_page_token end |
#recordings ⇒ Array<Google::Apis::MeetV2::Recording>
List of recordings in one page.
Corresponds to the JSON property recordings
359 360 361 |
# File 'lib/google/apis/meet_v2/classes.rb', line 359 def recordings @recordings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
366 367 368 369 |
# File 'lib/google/apis/meet_v2/classes.rb', line 366 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @recordings = args[:recordings] if args.key?(:recordings) end |