Class: Google::Apis::MeetV2::ListSmartNotesResponse
- Inherits:
-
Object
- Object
- Google::Apis::MeetV2::ListSmartNotesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/meet_v2/classes.rb,
lib/google/apis/meet_v2/representations.rb,
lib/google/apis/meet_v2/representations.rb
Overview
Response for ListSmartNotes method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Token to be circulated back for further List call if current List doesn't include all the smart notes.
-
#smart_notes ⇒ Array<Google::Apis::MeetV2::SmartNote>
List of smart notes in one page.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListSmartNotesResponse
constructor
A new instance of ListSmartNotesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListSmartNotesResponse
Returns a new instance of ListSmartNotesResponse.
387 388 389 |
# File 'lib/google/apis/meet_v2/classes.rb', line 387 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Token to be circulated back for further List call if current List doesn't
include all the smart notes. Unset if all smart notes are returned.
Corresponds to the JSON property nextPageToken
380 381 382 |
# File 'lib/google/apis/meet_v2/classes.rb', line 380 def next_page_token @next_page_token end |
#smart_notes ⇒ Array<Google::Apis::MeetV2::SmartNote>
List of smart notes in one page.
Corresponds to the JSON property smartNotes
385 386 387 |
# File 'lib/google/apis/meet_v2/classes.rb', line 385 def smart_notes @smart_notes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
392 393 394 395 |
# File 'lib/google/apis/meet_v2/classes.rb', line 392 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @smart_notes = args[:smart_notes] if args.key?(:smart_notes) end |