Class: Google::Apis::MeetV2::ListTranscriptEntriesResponse
- Inherits:
-
Object
- Object
- Google::Apis::MeetV2::ListTranscriptEntriesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/meet_v2/classes.rb,
lib/google/apis/meet_v2/representations.rb,
lib/google/apis/meet_v2/representations.rb
Overview
Response for ListTranscriptEntries method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Token to be circulated back for further List call if current List doesn't include all the transcript entries.
-
#transcript_entries ⇒ Array<Google::Apis::MeetV2::TranscriptEntry>
List of TranscriptEntries in one page.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListTranscriptEntriesResponse
constructor
A new instance of ListTranscriptEntriesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListTranscriptEntriesResponse
Returns a new instance of ListTranscriptEntriesResponse.
413 414 415 |
# File 'lib/google/apis/meet_v2/classes.rb', line 413 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Token to be circulated back for further List call if current List doesn't
include all the transcript entries. Unset if all entries are returned.
Corresponds to the JSON property nextPageToken
406 407 408 |
# File 'lib/google/apis/meet_v2/classes.rb', line 406 def next_page_token @next_page_token end |
#transcript_entries ⇒ Array<Google::Apis::MeetV2::TranscriptEntry>
List of TranscriptEntries in one page.
Corresponds to the JSON property transcriptEntries
411 412 413 |
# File 'lib/google/apis/meet_v2/classes.rb', line 411 def transcript_entries @transcript_entries end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
418 419 420 421 |
# File 'lib/google/apis/meet_v2/classes.rb', line 418 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @transcript_entries = args[:transcript_entries] if args.key?(:transcript_entries) end |