Class: Google::Apis::MeetV2::ModerationRestrictions
- Inherits:
-
Object
- Object
- Google::Apis::MeetV2::ModerationRestrictions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/meet_v2/classes.rb,
lib/google/apis/meet_v2/representations.rb,
lib/google/apis/meet_v2/representations.rb
Overview
Defines restrictions for features when the meeting is moderated.
Instance Attribute Summary collapse
-
#chat_restriction ⇒ String
Defines who has permission to send chat messages in the meeting space.
-
#default_join_as_viewer_type ⇒ String
Defines whether to restrict the default role assigned to users as viewer.
-
#present_restriction ⇒ String
Defines who has permission to share their screen in the meeting space.
-
#reaction_restriction ⇒ String
Defines who has permission to send reactions in the meeting space.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ModerationRestrictions
constructor
A new instance of ModerationRestrictions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ModerationRestrictions
Returns a new instance of ModerationRestrictions.
474 475 476 |
# File 'lib/google/apis/meet_v2/classes.rb', line 474 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chat_restriction ⇒ String
Defines who has permission to send chat messages in the meeting space.
Corresponds to the JSON property chatRestriction
457 458 459 |
# File 'lib/google/apis/meet_v2/classes.rb', line 457 def chat_restriction @chat_restriction end |
#default_join_as_viewer_type ⇒ String
Defines whether to restrict the default role assigned to users as viewer.
Corresponds to the JSON property defaultJoinAsViewerType
462 463 464 |
# File 'lib/google/apis/meet_v2/classes.rb', line 462 def default_join_as_viewer_type @default_join_as_viewer_type end |
#present_restriction ⇒ String
Defines who has permission to share their screen in the meeting space.
Corresponds to the JSON property presentRestriction
467 468 469 |
# File 'lib/google/apis/meet_v2/classes.rb', line 467 def present_restriction @present_restriction end |
#reaction_restriction ⇒ String
Defines who has permission to send reactions in the meeting space.
Corresponds to the JSON property reactionRestriction
472 473 474 |
# File 'lib/google/apis/meet_v2/classes.rb', line 472 def reaction_restriction @reaction_restriction end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
479 480 481 482 483 484 |
# File 'lib/google/apis/meet_v2/classes.rb', line 479 def update!(**args) @chat_restriction = args[:chat_restriction] if args.key?(:chat_restriction) @default_join_as_viewer_type = args[:default_join_as_viewer_type] if args.key?(:default_join_as_viewer_type) @present_restriction = args[:present_restriction] if args.key?(:present_restriction) @reaction_restriction = args[:reaction_restriction] if args.key?(:reaction_restriction) end |