Class: Google::Apis::MeetV2::Participant
- Inherits:
-
Object
- Object
- Google::Apis::MeetV2::Participant
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/meet_v2/classes.rb,
lib/google/apis/meet_v2/representations.rb,
lib/google/apis/meet_v2/representations.rb
Overview
User who attended or is attending a conference.
Instance Attribute Summary collapse
-
#anonymous_user ⇒ Google::Apis::MeetV2::AnonymousUser
User who joins anonymously (meaning not signed into a Google Account).
-
#earliest_start_time ⇒ String
Output only.
-
#latest_end_time ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#phone_user ⇒ Google::Apis::MeetV2::PhoneUser
User dialing in from a phone where the user's identity is unknown because they haven't signed in with a Google Account.
-
#signedin_user ⇒ Google::Apis::MeetV2::SignedinUser
A signed-in user can be: a) An individual joining from a personal computer, mobile device, or through companion mode.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Participant
constructor
A new instance of Participant.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Participant
Returns a new instance of Participant.
529 530 531 |
# File 'lib/google/apis/meet_v2/classes.rb', line 529 def initialize(**args) update!(**args) end |
Instance Attribute Details
#anonymous_user ⇒ Google::Apis::MeetV2::AnonymousUser
User who joins anonymously (meaning not signed into a Google Account).
Corresponds to the JSON property anonymousUser
497 498 499 |
# File 'lib/google/apis/meet_v2/classes.rb', line 497 def anonymous_user @anonymous_user end |
#earliest_start_time ⇒ String
Output only. Time when the participant first joined the meeting.
Corresponds to the JSON property earliestStartTime
502 503 504 |
# File 'lib/google/apis/meet_v2/classes.rb', line 502 def earliest_start_time @earliest_start_time end |
#latest_end_time ⇒ String
Output only. Time when the participant left the meeting for the last time.
This can be null if it's an active meeting.
Corresponds to the JSON property latestEndTime
508 509 510 |
# File 'lib/google/apis/meet_v2/classes.rb', line 508 def latest_end_time @latest_end_time end |
#name ⇒ String
Output only. Resource name of the participant. Format: conferenceRecords/
conference_record/participants/participant`
Corresponds to the JSON propertyname`
514 515 516 |
# File 'lib/google/apis/meet_v2/classes.rb', line 514 def name @name end |
#phone_user ⇒ Google::Apis::MeetV2::PhoneUser
User dialing in from a phone where the user's identity is unknown because they
haven't signed in with a Google Account.
Corresponds to the JSON property phoneUser
520 521 522 |
# File 'lib/google/apis/meet_v2/classes.rb', line 520 def phone_user @phone_user end |
#signedin_user ⇒ Google::Apis::MeetV2::SignedinUser
A signed-in user can be: a) An individual joining from a personal computer,
mobile device, or through companion mode. b) A robot account used by
conference room devices.
Corresponds to the JSON property signedinUser
527 528 529 |
# File 'lib/google/apis/meet_v2/classes.rb', line 527 def signedin_user @signedin_user end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
534 535 536 537 538 539 540 541 |
# File 'lib/google/apis/meet_v2/classes.rb', line 534 def update!(**args) @anonymous_user = args[:anonymous_user] if args.key?(:anonymous_user) @earliest_start_time = args[:earliest_start_time] if args.key?(:earliest_start_time) @latest_end_time = args[:latest_end_time] if args.key?(:latest_end_time) @name = args[:name] if args.key?(:name) @phone_user = args[:phone_user] if args.key?(:phone_user) @signedin_user = args[:signedin_user] if args.key?(:signedin_user) end |