Class: Google::Apis::MeetV2::PhoneAccess

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/meet_v2/classes.rb,
lib/google/apis/meet_v2/representations.rb,
lib/google/apis/meet_v2/representations.rb

Overview

Phone access contains information required to dial into a conference using a regional phone number and a PIN that is specific to that phone number.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PhoneAccess

Returns a new instance of PhoneAccess.



607
608
609
# File 'lib/google/apis/meet_v2/classes.rb', line 607

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#language_codeString

The BCP 47/LDML language code for the language associated with this phone access. To be parsed by the i18n LanguageCode utility. Examples: "es-419" for Latin American Spanish, "fr-CA" for Canadian French. Corresponds to the JSON property languageCode

Returns:

  • (String)


587
588
589
# File 'lib/google/apis/meet_v2/classes.rb', line 587

def language_code
  @language_code
end

#phone_numberString

The phone number to dial for this meeting space in E.164 format. Full phone number with a leading '+' character. Corresponds to the JSON property phoneNumber

Returns:

  • (String)


593
594
595
# File 'lib/google/apis/meet_v2/classes.rb', line 593

def phone_number
  @phone_number
end

#pinString

The PIN that users must enter after dialing the given number. The PIN consists of only decimal digits and the length may vary. Corresponds to the JSON property pin

Returns:

  • (String)


599
600
601
# File 'lib/google/apis/meet_v2/classes.rb', line 599

def pin
  @pin
end

#region_codeString

The CLDR/ISO 3166 region code for the country associated with this phone access. To be parsed by the i18n RegionCode utility. Example: "SE" for Sweden. Corresponds to the JSON property regionCode

Returns:

  • (String)


605
606
607
# File 'lib/google/apis/meet_v2/classes.rb', line 605

def region_code
  @region_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



612
613
614
615
616
617
# File 'lib/google/apis/meet_v2/classes.rb', line 612

def update!(**args)
  @language_code = args[:language_code] if args.key?(:language_code)
  @phone_number = args[:phone_number] if args.key?(:phone_number)
  @pin = args[:pin] if args.key?(:pin)
  @region_code = args[:region_code] if args.key?(:region_code)
end