Class: Google::Apis::MeetV2::Recording
- Inherits:
-
Object
- Object
- Google::Apis::MeetV2::Recording
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/meet_v2/classes.rb,
lib/google/apis/meet_v2/representations.rb,
lib/google/apis/meet_v2/representations.rb
Overview
Metadata about a recording created during a conference.
Instance Attribute Summary collapse
-
#drive_destination ⇒ Google::Apis::MeetV2::DriveDestination
Export location where a recording file is saved in Google Drive.
-
#end_time ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Recording
constructor
A new instance of Recording.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Recording
Returns a new instance of Recording.
671 672 673 |
# File 'lib/google/apis/meet_v2/classes.rb', line 671 def initialize(**args) update!(**args) end |
Instance Attribute Details
#drive_destination ⇒ Google::Apis::MeetV2::DriveDestination
Export location where a recording file is saved in Google Drive.
Corresponds to the JSON property driveDestination
647 648 649 |
# File 'lib/google/apis/meet_v2/classes.rb', line 647 def drive_destination @drive_destination end |
#end_time ⇒ String
Output only. Timestamp when the recording ended.
Corresponds to the JSON property endTime
652 653 654 |
# File 'lib/google/apis/meet_v2/classes.rb', line 652 def end_time @end_time end |
#name ⇒ String
Output only. Resource name of the recording. Format: conferenceRecords/
conference_record/recordings/recordingwhererecording`is a 1:1
mapping to each unique recording session during the conference.
Corresponds to the JSON propertyname`
659 660 661 |
# File 'lib/google/apis/meet_v2/classes.rb', line 659 def name @name end |
#start_time ⇒ String
Output only. Timestamp when the recording started.
Corresponds to the JSON property startTime
664 665 666 |
# File 'lib/google/apis/meet_v2/classes.rb', line 664 def start_time @start_time end |
#state ⇒ String
Output only. Current state.
Corresponds to the JSON property state
669 670 671 |
# File 'lib/google/apis/meet_v2/classes.rb', line 669 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
676 677 678 679 680 681 682 |
# File 'lib/google/apis/meet_v2/classes.rb', line 676 def update!(**args) @drive_destination = args[:drive_destination] if args.key?(:drive_destination) @end_time = args[:end_time] if args.key?(:end_time) @name = args[:name] if args.key?(:name) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) end |