Class: Google::Apis::MeetV2::SpaceConfig
- Inherits:
-
Object
- Object
- Google::Apis::MeetV2::SpaceConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/meet_v2/classes.rb,
lib/google/apis/meet_v2/representations.rb,
lib/google/apis/meet_v2/representations.rb
Overview
The configuration pertaining to a meeting space.
Instance Attribute Summary collapse
-
#access_type ⇒ String
Access type of the meeting space that determines who can join without knocking.
-
#artifact_config ⇒ Google::Apis::MeetV2::ArtifactConfig
Configuration related to meeting artifacts potentially generated by this meeting space.
-
#attendance_report_generation_type ⇒ String
Whether attendance report is enabled for the meeting space.
-
#entry_point_access ⇒ String
Defines the entry points that can be used to join meetings hosted in this meeting space.
-
#moderation ⇒ String
The pre-configured moderation mode for the Meeting.
-
#moderation_restrictions ⇒ Google::Apis::MeetV2::ModerationRestrictions
Defines restrictions for features when the meeting is moderated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SpaceConfig
constructor
A new instance of SpaceConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SpaceConfig
Returns a new instance of SpaceConfig.
910 911 912 |
# File 'lib/google/apis/meet_v2/classes.rb', line 910 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_type ⇒ String
Access type of the meeting space that determines who can join without knocking.
Default: The user's default access settings. Controlled by the user's admin
for enterprise users or RESTRICTED.
Corresponds to the JSON property accessType
880 881 882 |
# File 'lib/google/apis/meet_v2/classes.rb', line 880 def access_type @access_type end |
#artifact_config ⇒ Google::Apis::MeetV2::ArtifactConfig
Configuration related to meeting artifacts potentially generated by this
meeting space.
Corresponds to the JSON property artifactConfig
886 887 888 |
# File 'lib/google/apis/meet_v2/classes.rb', line 886 def artifact_config @artifact_config end |
#attendance_report_generation_type ⇒ String
Whether attendance report is enabled for the meeting space.
Corresponds to the JSON property attendanceReportGenerationType
891 892 893 |
# File 'lib/google/apis/meet_v2/classes.rb', line 891 def attendance_report_generation_type @attendance_report_generation_type end |
#entry_point_access ⇒ String
Defines the entry points that can be used to join meetings hosted in this
meeting space. Default: EntryPointAccess.ALL
Corresponds to the JSON property entryPointAccess
897 898 899 |
# File 'lib/google/apis/meet_v2/classes.rb', line 897 def entry_point_access @entry_point_access end |
#moderation ⇒ String
The pre-configured moderation mode for the Meeting. Default: Controlled by the
user's policies.
Corresponds to the JSON property moderation
903 904 905 |
# File 'lib/google/apis/meet_v2/classes.rb', line 903 def moderation @moderation end |
#moderation_restrictions ⇒ Google::Apis::MeetV2::ModerationRestrictions
Defines restrictions for features when the meeting is moderated.
Corresponds to the JSON property moderationRestrictions
908 909 910 |
# File 'lib/google/apis/meet_v2/classes.rb', line 908 def moderation_restrictions @moderation_restrictions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
915 916 917 918 919 920 921 922 |
# File 'lib/google/apis/meet_v2/classes.rb', line 915 def update!(**args) @access_type = args[:access_type] if args.key?(:access_type) @artifact_config = args[:artifact_config] if args.key?(:artifact_config) @attendance_report_generation_type = args[:attendance_report_generation_type] if args.key?(:attendance_report_generation_type) @entry_point_access = args[:entry_point_access] if args.key?(:entry_point_access) @moderation = args[:moderation] if args.key?(:moderation) @moderation_restrictions = args[:moderation_restrictions] if args.key?(:moderation_restrictions) end |