Class: Google::Apis::MeetV2::Transcript
- Inherits:
-
Object
- Object
- Google::Apis::MeetV2::Transcript
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/meet_v2/classes.rb,
lib/google/apis/meet_v2/representations.rb,
lib/google/apis/meet_v2/representations.rb
Overview
Metadata for a transcript generated from a conference. It refers to the ASR ( Automatic Speech Recognition) result of user's speech during the conference.
Instance Attribute Summary collapse
-
#docs_destination ⇒ Google::Apis::MeetV2::DocsDestination
Google Docs location where the transcript file is saved.
-
#end_time ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Transcript
constructor
A new instance of Transcript.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Transcript
Returns a new instance of Transcript.
957 958 959 |
# File 'lib/google/apis/meet_v2/classes.rb', line 957 def initialize(**args) update!(**args) end |
Instance Attribute Details
#docs_destination ⇒ Google::Apis::MeetV2::DocsDestination
Google Docs location where the transcript file is saved.
Corresponds to the JSON property docsDestination
933 934 935 |
# File 'lib/google/apis/meet_v2/classes.rb', line 933 def docs_destination @docs_destination end |
#end_time ⇒ String
Output only. Timestamp when the transcript stopped.
Corresponds to the JSON property endTime
938 939 940 |
# File 'lib/google/apis/meet_v2/classes.rb', line 938 def end_time @end_time end |
#name ⇒ String
Output only. Resource name of the transcript. Format: conferenceRecords/
conference_record/transcripts/transcript, wheretranscript`is a 1:1
mapping to each unique transcription session of the conference.
Corresponds to the JSON propertyname`
945 946 947 |
# File 'lib/google/apis/meet_v2/classes.rb', line 945 def name @name end |
#start_time ⇒ String
Output only. Timestamp when the transcript started.
Corresponds to the JSON property startTime
950 951 952 |
# File 'lib/google/apis/meet_v2/classes.rb', line 950 def start_time @start_time end |
#state ⇒ String
Output only. Current state.
Corresponds to the JSON property state
955 956 957 |
# File 'lib/google/apis/meet_v2/classes.rb', line 955 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
962 963 964 965 966 967 968 |
# File 'lib/google/apis/meet_v2/classes.rb', line 962 def update!(**args) @docs_destination = args[:docs_destination] if args.key?(:docs_destination) @end_time = args[:end_time] if args.key?(:end_time) @name = args[:name] if args.key?(:name) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) end |