Class: Google::Apis::MeetV2::TranscriptionConfig
- Inherits:
-
Object
- Object
- Google::Apis::MeetV2::TranscriptionConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/meet_v2/classes.rb,
lib/google/apis/meet_v2/representations.rb,
lib/google/apis/meet_v2/representations.rb
Overview
Configuration related to transcription in a meeting space.
Instance Attribute Summary collapse
-
#auto_transcription_generation ⇒ String
Defines whether the content of a meeting is automatically transcribed when someone with the privilege to transcribe joins the meeting.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TranscriptionConfig
constructor
A new instance of TranscriptionConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TranscriptionConfig
Returns a new instance of TranscriptionConfig.
1033 1034 1035 |
# File 'lib/google/apis/meet_v2/classes.rb', line 1033 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_transcription_generation ⇒ String
Defines whether the content of a meeting is automatically transcribed when
someone with the privilege to transcribe joins the meeting.
Corresponds to the JSON property autoTranscriptionGeneration
1031 1032 1033 |
# File 'lib/google/apis/meet_v2/classes.rb', line 1031 def auto_transcription_generation @auto_transcription_generation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1038 1039 1040 |
# File 'lib/google/apis/meet_v2/classes.rb', line 1038 def update!(**args) @auto_transcription_generation = args[:auto_transcription_generation] if args.key?(:auto_transcription_generation) end |